Welcome to python-daachorse's documentation!
============================================

`daachorse`_ is a fast implementation of the Aho-Corasick algorithm using the compact double-array
data structure. This is a Python wrapper.

.. _daachorse: https://github.com/daac-tools/daachorse

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
